##
##  thttpd.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2018 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         thttpd
Summary:      Tiny HTTP Daemon
URL:          http://www.acme.com/software/thttpd/
Vendor:       Jef Poskanzer
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        Web
License:      MIT-style
Version:      2.29
Release:      20180527

#   package options
%option       with_fsl  yes

#   list of sources
Source0:      http://www.acme.com/software/thttpd/thttpd-%{version}.tar.gz
Source1:      rc.thttpd
Source2:      fsl.thttpd
Source3:      thttpd.conf
Patch0:       thttpd.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make
PreReq:       OpenPKG, openpkg >= 20160101
%if "%{with_fsl}" == "yes"
BuildPreReq:  fsl
PreReq:       fsl
%endif

%description
    thttpd is a simple, small, fast, and secure HTTP server. It doesn't
    have a lot of special features, but it suffices for most uses of
    the web, it's about as fast as the best full-featured servers
    (Apache, NCSA Netscape), and it has one extremely useful feature
    (URL-traffic-based throttling) that no other server currently has.

%track
    prog thttpd = {
        version   = %{version}
        url       = http://www.acme.com/software/thttpd/
        regex     = thttpd-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    #   configure program
    export CC="%{l_cc}"
    export CFLAGS="%{l_cflags -O}"
    export CPPFLAGS="%{l_cppflags}"
    export LDFLAGS="%{l_ldflags} %{l_fsl_ldflags}"
    export LIBS="%{l_fsl_libs}"
    case "%{l_platform -t}" in
        *-sunos* ) LIBS="$LIBS -ldl" ;;
    esac
    echo "ac_cv_lbl_static_flag=unknown" >config.cache
    ./configure \
        --cache-file=./config.cache \
        --prefix=%{l_prefix}

    #   build program
    %{l_make} %{l_mflags}

%install
    #   install program
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man8 \
        $RPM_BUILD_ROOT%{l_prefix}/cgi
    %{l_make} %{l_mflags} install \
        DESTDIR=$RPM_BUILD_ROOT

    #   post-adjust and strip-down installation
    mv  $RPM_BUILD_ROOT%{l_prefix}/sbin/htpasswd \
        $RPM_BUILD_ROOT%{l_prefix}/bin/htpasswd
    mv  $RPM_BUILD_ROOT%{l_prefix}/sbin/makeweb \
        $RPM_BUILD_ROOT%{l_prefix}/bin/makeweb
    strip $RPM_BUILD_ROOT%{l_prefix}/sbin/* >/dev/null 2>&1 || true

    #   install default configuration
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/thttpd
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE thttpd.conf} $RPM_BUILD_ROOT%{l_prefix}/etc/thttpd/

    #   create directory for pid and log files
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/var/thttpd

    #   install run-command script
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.thttpd} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install OSSP fsl configuration
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/fsl
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE fsl.thttpd} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/fsl/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/fsl/*' \
        '%config %{l_prefix}/etc/thttpd/*' \
        '%attr(755,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/thttpd'

%files -f files

%clean

